### 0.12.5 {small}`2025-05-23`

```{rubric} Features
```
* Optimize performance of `pp.harmony_integrate` with integrated benchmarking for `colsum_algo` {pr}`373` {smaller}`S Dicks`

```{rubric} Performance
```
* Make `pp.regress_out` more memory efficient {pr}`370` {smaller}`S Dicks`
* Improves performance of `pp.harmony_integrate` even more for larger datasets {pr}`373` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* remove `random_state` from cuml's `PCA` and `TruncatedSVD` {pr}`368` {smaller}`S Dicks`
* fixes a error with `pp.harmony_integrate` where `E` didn't update correctly {pr}`373` {smaller}`S Dicks`

```{rubric} Misc
```
* adds tests for RAPIDS upcoming release {pr}`368` {smaller}`S Dicks`
